@@ -1,5 +1,4 @@
 package Mira::CLI::Command::new;
-$Mira::CLI::Command::new::VERSION = '0.07';
 
 use strict;
 use warnings;
@@ -7,6 +6,7 @@ use warnings;
 use App::Cmd::Setup -command;
 
 use 5.012;
+our $VERSION = $Mira::VERSION;
 
 use Cwd;
 use File::Spec;
@@ -62,20 +62,22 @@ sub execute {
   $opt->{floor} = lc($opt->{floor});
   my $floor = $opt->{floor};
 
+  my $ext = $config->{$floor}->{default_extension} ? $config->{$floor}->{default_extension} : 'md';
+  $ext =~ s/\.+//;
 
   my %segments;
   $segments{utid} = $utid;
   $segments{date} = $now_date;
   $segments{title} = $opt->{title};
-  if ($config->{$floor}->{default_body_format} and $config->{$floor}->{default_body_format} =~ /^(markdown|md|html|text|txt|bbcode|textile)$/i)
+  if ($config->{$floor}->{default_markup} and $config->{$floor}->{default_markup} =~ /^(markdown|md|html|text|txt|bbcode|textile)$/i)
   {
-  	$segments{'body-format'} = $config->{$floor}->{default_body_format};
-  } elsif ($config->{_default}->{default_body_format} and $config->{_default}->{default_body_format} =~ /^(markdown|md|html|text|txt|bbcode|textile)$/i)
+  	$segments{markup} = $config->{$floor}->{default_markup};
+  } elsif ($config->{_default}->{default_markup} and $config->{_default}->{default_markup} =~ /^(markdown|md|html|text|txt|bbcode|textile)$/i)
   {
-  	$segments{'body-format'} = $config->{_default}->{default_body_format};
+  	$segments{markup} = $config->{_default}->{default_markup};
   } else
   {
-  	$segments{'body-format'} = "markdown";
+  	$segments{markup} = "markdown";
   }
   $segments{author} = $config->{$floor}->{author} ? $config->{$floor}->{author} : ($config->{_default}->{author} ? $config->{_default}->{author} : $ENV{USER});
 
@@ -95,9 +97,7 @@ sub execute {
   } else
   {
   	$content =<<"END_CNTNT";
-_index:
 _permalink:
-title:
 author:
 categories:
   -
@@ -115,14 +115,14 @@ $title =~ s/[\W]+/_/g;
   make_path $target_post_dir unless -d $target_post_dir;
 
   my $target_post_file;
-  if (! -f catfile($target_post_dir, "$year-$mon-$mday-$title.pen")) {
-  	$target_post_file = catfile($target_post_dir, "$year-$mon-$mday-$title.pen");
+  if (! -f catfile($target_post_dir, "$year-$mon-$mday-$title.$ext")) {
+  	$target_post_file = catfile($target_post_dir, "$year-$mon-$mday-$title.$ext");
   } else {
-  	print "/$opt->{floor}/$year-$mon-$mday-$title.pen already exist\n";
+  	print "/$opt->{floor}/$year-$mon-$mday-$title.$ext already exist\n";
   	while (1) {
   		state $nfid = 2;
   		$nfid = sprintf "%02d", $nfid;
-  		$target_post_file = catfile($target_post_dir, "$year-$mon-$mday-$title-$nfid.pen");
+  		$target_post_file = catfile($target_post_dir, "$year-$mon-$mday-$title-$nfid.$ext");
   		last unless (-e $target_post_file);
   		$nfid++;
   	}
@@ -135,7 +135,7 @@ $title =~ s/[\W]+/_/g;
   print $fh "_index:\n";
   print $fh $content."\n";
   print $fh "author: $segments{author}\n";
-  print $fh "body-format: $segments{'body-format'}\n";
+  print $fh "_markup: $segments{markup}\n";
   print $fh "---\n";
   close $fh;
   say "$target_post_file created";
