@@ -1,11 +1,12 @@
 package Mira::View::Main;
-$Mira::View::Main::VERSION = '0.07';
 
 use strict;
 use warnings;
 use utf8;
 use 5.012;
+our $VERSION = $Mira::VERSION;
 
+use File::Spec;
 use File::Spec::Functions;
 use Template;
 
@@ -15,10 +16,11 @@ sub template {
 
   my $allposts = $switches{posts}; #all utids reverse sorted
   my $allentries = $switches{allentries}; #all entries data hash
-  my $floors = $switches{floors};
+#  my $floors = $switches{floors};
   my $config = $switches{config}; #configs
   my $pensource = $switches{pensource};
   my $floor_data = $switches{floor_data};
+  my $build = $switches{build};
 
   my $template_root = catdir($pensource,'template', $config->{_default}->{template});
 
@@ -26,21 +28,25 @@ sub template {
       INCLUDE_PATH => [$template_root, catdir($template_root, 'include') ],
       INTERPOLATE  => 1,
       ENCODING => 'utf8',
+      START_TAG => quotemeta('{{'),
+      END_TAG   => quotemeta('}}'),
   }) || die "$Template::ERROR\n";
 
   my $vars = {
-  	 TITLE => $config->{_default}->{title},
-     DESCRIPTION => $config->{_default}->{description},
-     URL => $config->{_default}->{url},
-     ROOT => $config->{_default}->{root},
-     STATIC => $config->{_default}->{static},
-  	 IMGURL => $config->{_default}->{imgurl},
-     AUTHOR => $config->{_default}->{author},
-     EMAIL => $config->{_default}->{email},
+  	 MainTITLE => $config->{_default}->{title},
+     MainDESCRIPTION => $config->{_default}->{description},
+     MainURL => $config->{_default}->{url},
+     MainROOT => $config->{_default}->{root},
+     MainSTATIC => $config->{_default}->{static},
+     MainIMAGEURL => $config->{_default}->{imageurl},
+     MainAUTHOR => $config->{_default}->{author},
+     MainEMAIL => $config->{_default}->{email},
      PageTITLE => $config->{_default}->{title},
-     Entries  => $allentries,
-     Floors => $floor_data,
-     Posts => $allposts,
+     ENTRIES  => $allentries,
+     FLOORS => $floor_data,
+     UTIDS => $allposts,
+     MAIN => $config->{_default},
+     BUILD => $build,
      FarsiNum => bless(\&farsinum, 'mira'),
    };
 
@@ -50,13 +56,15 @@ sub template {
      return $string;
    }
 
-  $vars->{URL} =~ s"(?<!http:)/+"/"g;
-  $vars->{URL} =~ s"/$""g;
+   #$vars->{MainURL} =~ s"(?<!http:)/+"/"g;
+   $vars->{MainURL} =~ s{(?<!:)/+}{/}g;
+   $vars->{MainURL} =~ s{/$}{}g;
+
+   $vars->{MainROOT} =~ s{^(.*?):/+}{/}g;
+   $vars->{MainROOT} = "/" . $vars->{MainROOT} if $vars->{MainROOT} !~ m:^/:;
+   $vars->{MainROOT} =~ s{/+}{/}g;
+   $vars->{MainROOT} =~ s{/$}{}g unless $vars->{MainROOT} eq "/";
 
-  $vars->{ROOT} =~ s"^http:/+"/"g;
-  $vars->{ROOT} = "/" . $vars->{ROOT};
-  $vars->{ROOT} =~ s"/+"/"g;
-  $vars->{ROOT} =~ s"/$""g;
 
   my $index = catfile($pensource, 'public', $config->{_default}->{root}, 'index.html');
   $root_index->process('main.tt2', $vars, $index, { binmode => ':utf8' })
